/**
 * This Program is a small example for how to use Jasperreports
 * 
 * Copyright (C) 2006 Alexander Merz
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package com.alexmerz.jasperreports;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRExporter;
import net.sf.jasperreports.engine.JRExporterParameter;
import net.sf.jasperreports.engine.JasperCompileManager;
import net.sf.jasperreports.engine.JasperFillManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.engine.data.JRMapCollectionDataSource;
import net.sf.jasperreports.engine.export.JRCsvExporter;
import net.sf.jasperreports.engine.export.JRCsvExporterParameter;
import net.sf.jasperreports.engine.export.JRHtmlExporter;
import net.sf.jasperreports.engine.export.JRHtmlExporterParameter;
import net.sf.jasperreports.engine.export.JRPdfExporter;
import net.sf.jasperreports.engine.export.JRPdfExporterParameter;
import net.sf.jasperreports.engine.export.JRRtfExporter;
import net.sf.jasperreports.engine.export.JRTextExporter;
import net.sf.jasperreports.engine.export.JRTextExporterParameter;
import net.sf.jasperreports.engine.export.JRXlsExporter;
import net.sf.jasperreports.engine.export.JRXmlExporter;
import net.sf.jasperreports.engine.export.JRXmlExporterParameter;

public class Example15 {

	private static Collection<Map> coll = new ArrayList<Map>();	
	/**
	 * @param args unused
	 * @throws ClassNotFoundException 
	 * @throws SQLException 
	 */
	public static void main(String[] args) throws ClassNotFoundException, SQLException {
		JasperReport jasperReport;
		JasperPrint jasperPrint;
		HashMap<String, String> parameter = new HashMap<String, String>();		
			
		createData();
		
		try {
			
			JRMapCollectionDataSource ds = new JRMapCollectionDataSource(coll);
			
			jasperReport = JasperCompileManager.compileReport("JRXML/Example15.jrxml");			
		    jasperPrint = JasperFillManager.fillReport(jasperReport, parameter, ds);
		    
		    JRExporter exporter = new JRPdfExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.pdf");
		    exporter.setParameter(JRPdfExporterParameter.IS_ENCRYPTED, new Boolean(true));
		    exporter.setParameter(JRPdfExporterParameter.USER_PASSWORD, "secret");
		    exporter.exportReport();
		    
		    exporter = new JRHtmlExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.html");
		    exporter.setParameter(JRHtmlExporterParameter.BETWEEN_PAGES_HTML, "<hr/>");		    
		    exporter.exportReport();		    
		    
		    exporter = new JRXmlExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.xml");
		    exporter.setParameter(JRXmlExporterParameter.IS_EMBEDDING_IMAGES, new Boolean(true));		    
		    exporter.exportReport();
		    
		    exporter = new JRXlsExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.xls");
		    exporter.exportReport();
		    
		    exporter = new JRTextExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.txt");
		    exporter.setParameter(JRTextExporterParameter.PAGE_WIDTH, new Integer(79));
		    exporter.setParameter(JRTextExporterParameter.CHARACTER_HEIGHT, new Integer(12));		    
		    exporter.exportReport();
		    
		    exporter = new JRCsvExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.csv");
		    exporter.setParameter(JRCsvExporterParameter.FIELD_DELIMITER, ";");
		    exporter.setParameter(JRCsvExporterParameter.RECORD_DELIMITER, "\n");		    
		    exporter.exportReport();
		    
		    exporter = new JRRtfExporter();
		    exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
		    exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME,  "output/Example15.rtf");		    		   
		    exporter.exportReport();		    
		}
		catch (JRException e) {
		      e.printStackTrace();
		}

	}
	
	private static void createData() {
		Map<String, Object> m = new HashMap<String, Object>();		
		m.put("betrag", new Float(4.95));
		m.put("betreff", "iX");
		coll.add(m);
		
		m = new HashMap<String, Object>();
		m.put("betrag", new Float(9.90));
		m.put("betreff", "PHP Magazin");
		coll.add(m);
		
		m = new HashMap<String, Object>();
		m.put("betrag", new Float(34.00));
		m.put("betreff", "PHP 5 - Einsteigen und Durchstarten");
		coll.add(m);
		
		m = new HashMap<String, Object>();
		m.put("betrag", new Float(49.90));
		m.put("betreff", "JasperReports Ultimate Guide");
		coll.add(m);		
		
		m = new HashMap<String, Object>();
		m.put("betrag", new Float(24.00));
		m.put("betreff", "California Earth");
		coll.add(m);		
	}

}
